@@ -121,11 +121,12 @@ class FeatureSelection(object):
                 print >> sys.stderr, "  %d    %f  %f  %f" % (k, train_results['AUROC'], train_results['TrainingError'], test_results['TestError'])
                 
                 if best_features is None or test_results['TestError'] < best_features[0]:
-                    best_features = (test_results['TestError'], selected[:k])
+                    best_features = (test_results['TestError'], test_results['TrainingError'], selected[:k])
             
-            feature_sets.append( (best_features[0], best_features[1]) )
+            feature_sets.append( best_features )
         
-        return sorted(feature_sets)[0][1]
+        best_feature_set = sorted(feature_sets)[0]
+        return {'SelectedFeatures':best_feature_set[2], 'TestError':best_feature_set[0], 'TrainingError':best_feature_set[1]}
 
 class MachineLearning(object):
     """
